"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ngAdd = void 0;
const path = require("node:path");
const schematics_1 = require("@angular-devkit/schematics");
const linter_1 = require("./linter");
const reportMissingSchematicsDep = (logger) => (reason) => {
    logger.error(`[ERROR]: Adding @o3r/eslint-config-otter has failed.
You need to install '@o3r/schematics' package to be able to use the eslint-config-otter package. Please run 'ng add @o3r/schematics' .`);
    throw reason;
};
/**
 * Add Otter eslint-config to an Angular Project
 * @param options
 */
function ngAddFn(options) {
    /* ng add rules */
    return async (tree, context) => {
        const devDependenciesToInstall = [
            'eslint',
            '@angular-eslint/builder',
            '@angular-eslint/eslint-plugin',
            '@stylistic/eslint-plugin-ts',
            '@typescript-eslint/parser',
            '@typescript-eslint/eslint-plugin',
            '@typescript-eslint/utils',
            'eslint-plugin-jest',
            'eslint-plugin-jsdoc',
            'eslint-plugin-prefer-arrow',
            'eslint-plugin-unicorn',
            'jest',
            'jsonc-eslint-parser',
            'yaml-eslint-parser'
        ];
        const { getExternalDependenciesVersionRange, addVsCodeRecommendations, setupDependencies, getWorkspaceConfig, getO3rPeerDeps, getProjectNewDependenciesTypes, removePackages, getPackageInstallConfig } = await Promise.resolve().then(() => require('@o3r/schematics'));
        const depsInfo = getO3rPeerDeps(path.resolve(__dirname, '..', '..', 'package.json'), true, /^@(?:o3r|ama-sdk|eslint-)/);
        const workspaceProject = options.projectName ? getWorkspaceConfig(tree)?.projects[options.projectName] : undefined;
        const linterSchematicsFolder = __dirname;
        const { NodeDependencyType } = await Promise.resolve().then(() => require('@schematics/angular/utility/dependencies'));
        const packageJsonPath = path.resolve(__dirname, '..', '..', 'package.json');
        const dependencies = depsInfo.o3rPeerDeps.reduce((acc, dep) => {
            acc[dep] = {
                inManifest: [{
                        range: `${options.exactO3rVersion ? '' : '~'}${depsInfo.packageVersion}`,
                        types: getProjectNewDependenciesTypes(workspaceProject)
                    }],
                ngAddOptions: { exactO3rVersion: options.exactO3rVersion }
            };
            return acc;
        }, getPackageInstallConfig(packageJsonPath, tree, options.projectName, true, !!options.exactO3rVersion));
        Object.entries(getExternalDependenciesVersionRange(devDependenciesToInstall, packageJsonPath, context.logger))
            .forEach(([dep, range]) => {
            dependencies[dep] = {
                inManifest: [{
                        range,
                        types: [NodeDependencyType.Dev]
                    }]
            };
        });
        return () => (0, schematics_1.chain)([
            removePackages(['@otter/eslint-config-otter', '@otter/eslint-plugin']),
            setupDependencies({
                projectName: options.projectName,
                dependencies,
                ngAddToRun: depsInfo.o3rPeerDeps
            }),
            addVsCodeRecommendations(['dbaeumer.vscode-eslint', 'stylelint.vscode-stylelint']),
            (0, linter_1.updateLinterConfigs)(options, linterSchematicsFolder)
        ])(tree, context);
    };
}
/**
 * Add Otter eslint-config to an Angular Project
 * @param options
 */
const ngAdd = (options) => async (_, { logger }) => {
    const { createOtterSchematic } = await Promise.resolve().then(() => require('@o3r/schematics')).catch(reportMissingSchematicsDep(logger));
    return createOtterSchematic(ngAddFn)(options);
};
exports.ngAdd = ngAdd;
//# sourceMappingURL=index.js.map